<?php

/**
 * @file
 * Plugin to provide access control/visibility based on a defined visibility schedule.
 */

$plugin = array(
  'title' => t('Scheduled Date'),
  'description' => t('Control access based on scheduled date.'),
  'callback' => 'panel_schedule_ctools_access_check',
  'settings form' => 'panel_schedule_ctools_access_settings',
  'summary' => 'panel_schedule_ctools_access_summary',
);

/**
 * Settings form
 */
function panel_schedule_ctools_access_settings($form, &$form_state, $conf) {
  $form['settings']['start_date'] = array(
    '#type'          => 'date_popup',
    '#title'         => t('Start Date'),
    '#default_value' => $conf['start_date'],
    '#date_format'   => variable_get('date_format_short', 'm/d/Y - H:i'),
    '#description'   => t('Date and time to start visibility'),
    '#required'      => TRUE,
  );
  $form['settings']['end_date'] = array(
    '#type'          => 'date_popup',
    '#title'         => t('End Date'),
    '#default_value' => $conf['end_date'],
    '#date_format'   => variable_get('date_format_short', 'm/d/Y - H:i'),
    '#description'   => t('Date and time to end visibility (Optional)'),
    '#required'      => FALSE,
  );
  return $form;
}

/**
 * Check for access.
 */
function panel_schedule_ctools_access_check($conf, $context) {
  if ($conf['end_date']) {
    if (REQUEST_TIME > strtotime($conf['end_date'])) {
      return FALSE;
    }
  }
  if (REQUEST_TIME >= strtotime($conf['start_date'])) {
    return TRUE;
  }

  return FALSE;
}

/**
 * Provide a summary description.
 */
function panel_schedule_ctools_access_summary($conf, $context) {
  if ($conf['end_date']) {
    return t('the page request occurs within the scheduled range: @start_date - @end_date', 
      array(
        '@start_date' => $conf['start_date'],
        '@end_date' => $conf['end_date']
      ));
  }
  else {
    return t('the page request occurs on or after the scheduled start date: @start_date', 
      array(
        '@start_date' => $conf['start_date']
      ));
  }
}
